from setuptools import setup

setup(
    name='proba_publ_proj',
    version='',
    packages=['tworz_imion_pac'],
    url='',
    license='',
    author='Monika',
    author_email='monikaa_sz@interia.pl',
    description='fajny program'
)
